@@ -15,7 +15,8 @@
 #'   If omitted, the current working directory will be used.
 #' @param loadAll If TRUE will load all files in \code{dir}. If FALSE, will load
 #'   a single file specified by \code{dir}. Default is TRUE.
-#' @param ext The extension to use for output files. Default is \code{.out}.
+#' @param filter A regular expression that matches the files to be loaded.
+#'   Default is \code{\\\\.out} which filters for standard apsim output files.
 #' @param returnFrame Return the data as a data frame or data table. Default is 
 #'   TRUE, FALSE returns a data table.
 #' @param n Read the first n files. Good for testing/debugging. Default is 0 
@@ -27,12 +28,12 @@
 #'   levels) found as extra columns. Default is TRUE.
 #' @export
 #' @examples
-#' \dontrun{genericLoadApsim("c:/outputs") # load everything in the outputs directory}
-#' \dontrun{genericLoadApsim("c:/outputs/simulation.out", loadAll=FALSE) 
+#' \dontrun{loadApsim("c:/outputs") # load everything in the outputs directory}
+#' \dontrun{loadApsim("c:/outputs/simulation.out", loadAll=FALSE) 
 #' # load a single file (note extension is required).}
-#' \dontrun{genericLoadApsim("c:/outputs", returnFrame=FALSE, fill=TRUE) 
+#' \dontrun{loadApsim("c:/outputs", returnFrame=FALSE, fill=TRUE) 
 #'   # load everything in the outputs directory, fill any missing columns and return a data table.}
-loadApsim <- compiler::cmpfun(function(dir = NULL, loadAll=TRUE, ext = ".out", returnFrame = TRUE, n = 0, fill=FALSE, addConstants=TRUE)
+loadApsim <- compiler::cmpfun(function(dir = NULL, loadAll=TRUE, filter = "\\.out", returnFrame = TRUE, n = 0, fill=FALSE, addConstants=TRUE)
 {    # this function is precompiled for a 10-12% performance increase
     if (loadAll){ 
         wd <- getwd()
@@ -42,7 +43,7 @@ loadApsim <- compiler::cmpfun(function(dir = NULL, loadAll=TRUE, ext = ".out", r
         else {
             dir <- getwd()
         }
-        files <- list.files(dir, paste(ext, "$", sep="")) # create a list of files
+        files <- list.files(pattern = paste(filter, "$", sep="")) # create a list of files
     } else {
         files <- dir
     }
@@ -92,7 +93,7 @@ loadApsim <- compiler::cmpfun(function(dir = NULL, loadAll=TRUE, ext = ".out", r
             count <- count + 1
         }
         close(con)
-        data <- read.table(f, skip=count, header=FALSE, col.names=colNames, na.strings = "?", stringsAsFactors=FALSE) # read the data
+        data <- read.table(f, skip=count, header=FALSE, col.names=colNames, na.strings = c("?", "*"), stringsAsFactors=FALSE) # read the data
         for(c in constants){
             data[[ncol(data) + 1]] <- c[2]
             colNames[length(colNames) + 1] <- c[1]
@@ -117,4 +118,39 @@ loadApsim <- compiler::cmpfun(function(dir = NULL, loadAll=TRUE, ext = ".out", r
     })
     if (loadAll) setwd(wd) #restore wd
     return(allData)
-})
\ No newline at end of file
+})
+
+#' Extract a token from a vector of strings.
+#' 
+#' Extract a token from a character vector in a data frame containing a number
+#' of delimited tokens. Specialised version of str_split that works on vectors.
+#' 
+#' By default loadApsim will automatically create columns from constants inside
+#' the output files. However sometimes you might want to extract values from 
+#' different data such as the file name. This is easy to do if the data is
+#' a fixed width, but it can be difficult when it's of variable length and
+#' delimited. str_split() is the most common way to deal with this sort of 
+#' data, but it doesn't work on a vector.
+#' 
+#' getToken takes a data frame, a column of type 'character', a seperator and a token position to return
+#' each token in the given position. It then appends the token as a new column.
+#' @param x A data frame
+#' @param cname The name of the column to extract a token from.
+#' @param pos The position of the desired token in the token string.
+#' @param sep The character to use as a seperator (e.g. ":", ";", etc.) Can be multi-character.
+#' @param colName A name for the new column.
+getToken <- function(x, cname, pos, sep, colName) {
+    if (is.null(cname) | length(cname) != 1)
+        stop("cname must be a character vector of length 1.")
+    
+    delims <- str_count(x[, cname], sep)
+    
+    if (min(delims) != max(delims))
+        stop ("Number of delimiters is not the same in all vector elements.")
+    
+    m<- str_split_fixed(x[, cname], "_",n= delims + 1)
+    
+    x <- cbind(x, m[, pos])
+    setnames(x, "m[, pos]", colName)
+    return(x)
+}
\ No newline at end of file
